/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.simplechannelplugin;

import org.tinygroup.cepcore.CEPCore;
import org.tinygroup.channel.ChannelInterface;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.plugin.impl.BasePlugin;

public class SimpleChannelPlugin extends BasePlugin{
	private static Logger logger = LoggerFactory.getLogger(SimpleChannelPlugin.class);
	private CEPCore cepcore;
	private ChannelInterface channel;
	public void init(){
		super.init();
		initChannel();
	}
	
	private void initChannel(){
		logger.logMessage(LogLevel.DEBUG, "初始化SimpleChannelProcessor");
		channel = (ChannelInterface)getService("simplechannel","1.0");
		logger.logMessage(LogLevel.DEBUG, "初始化SimpleChannelProcessor完成");
	}
	protected ClassLoader getThisClassLoader(){
		 return this.getClass().getClassLoader();
	}

	public void start(){
		logger.logMessage(LogLevel.DEBUG, "启动SimpleChannelPlugin");
		cepcore.registerEventProcessor(channel);
		logger.logMessage(LogLevel.DEBUG, "启动SimpleChannelPlugin完成");
	}
	public void pause() {
		logger.logMessage(LogLevel.DEBUG, "暂停SimpleChannelPlugin");
			cepcore.unregisterEventProcessor(channel);
		logger.logMessage(LogLevel.DEBUG, "暂停SimpleChannelPlugin完成");
	}

	public void stop() {
		logger.logMessage(LogLevel.DEBUG, "停止SimpleChannelPlugin");
		cepcore.unregisterEventProcessor(channel);
		logger.logMessage(LogLevel.DEBUG, "停止SimpleChannelPlugin完成");
	}

	public void destroy() {
		logger.logMessage(LogLevel.DEBUG, "销毁SimpleChannelPlugin");
		super.destroy();
		logger.logMessage(LogLevel.DEBUG, "销毁SimpleChannelPlugin完成");
	}
	
	public <T> void setService(T service, Class<T> clazz) {
		if (CEPCore.class.isAssignableFrom(clazz)) {
			if (service == null) {
				this.cepcore = null;
			} else {
				this.cepcore = (CEPCore) service;
			}
		}
		
	}
	
}
